@@ -1,11 +1,11 @@
 from typing import Dict, Union
 from functools import partial, wraps
 
-from pyot.utils.common import camelcase
+from pyot.utils.text import camelcase
 from .exceptions import NotFound
 
 
-class lazy_property:
+class lazy_property(property):
     """
     Decorator that converts a method with a single self argument into a
     property cached on the instance and inserted into the meta data dict using camelcase key.
@@ -17,11 +17,11 @@ class lazy_property:
     @staticmethod
     def func(instance): # pylint: disable=method-hidden
         raise TypeError(
-            'Cannot use cached_property instance without calling '
+            'Cannot use lazy_property instance without calling '
             '__set_name__() on it.'
         )
 
-    def __init__(self, func, name=None):
+    def __init__(self, func, name=None): # pylint: disable=super-init-not-called
         self.real_func = func
         self.key = camelcase(func.__name__)
         self.__doc__ = getattr(func, '__doc__')
@@ -32,7 +32,7 @@ class lazy_property:
             self.func = self.real_func
         elif name != self.name:
             raise TypeError(
-                "Cannot assign the same cached_property to two different names "
+                "Cannot assign the same lazy_property to two different names "
                 "(%r and %r)." % (self.name, name)
             )
 
@@ -47,6 +47,9 @@ class lazy_property:
         res = instance._meta.data[self.key] = instance.__dict__[self.name] = self.func(instance)
         return res
 
+    def __set__(self, obj, value):
+        raise AttributeError("can't set attribute")
+
 
 class cache_indexes:
 
@@ -60,8 +63,8 @@ class cache_indexes:
     def __call__(self, instance, data):
         try:
             return self.func(instance, self, data)
-        except KeyError:
-            raise NotFound("Request was successful but filtering gave no matching item")
+        except KeyError as e:
+            raise NotFound("Request was successful but filtering gave no matching item") from e
 
     @staticmethod
     def _get_index(name, data, key):
@@ -126,6 +129,9 @@ def laziable(obj):
         return True
     return False
 
+def parse_camelcase(kwargs: Dict) -> Dict:
+    return {camelcase(key): val for (key, val) in kwargs.items() if key != "self" and val is not None}
+
 
 def handle_import_error(module: ImportError):
     if isinstance(module, (ImportError, ValueError)):
