@@ -1,5 +1,12 @@
-from typing import List, Iterator
-from .__core__ import PyotCore, PyotStatic
+from typing import List, Iterator, TYPE_CHECKING, NoReturn
+
+from pyot.conf.model import models
+from pyot.core.functional import parse_camelcase
+from .base import PyotCore, PyotStatic
+
+if TYPE_CHECKING:
+    from .summoner import Summoner
+
 
 # PYOT STATIC OBJECTS
 
@@ -55,8 +62,8 @@ class League(PyotCore):
         rules = {"league_v4_league_by_league_id": ["id"]}
         renamed = {"league_id": "id"}
 
-    def __init__(self, id: str = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, id: str = None, platform: str = models.lol.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
 
 class ApexLeague(League):
@@ -64,17 +71,13 @@ class ApexLeague(League):
     id: str
 
     class Meta(League.Meta):
-        queue_list = ["RANKED_SOLO_5x5", "RANKED_FLEX_SR"]
+        pass
 
-    def __init__(self, queue: str = None, platform: str = None):
-        self._lazy_set(locals())
-
-    async def _setup(self):
-        if self.queue not in self._meta.queue_list:
-            raise AttributeError(f"Invalid 'queue' attribute, '{self.queue}' was given")
+    def __init__(self, queue: str = None, platform: str = models.lol.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
     @property
-    def league(self) -> "League":
+    def league(self) -> League:
         return League(id=self.id, platform=self.platform)
 
 
@@ -103,8 +106,8 @@ class SummonerLeague(PyotCore):
     class Meta(PyotCore.Meta):
         rules = {"league_v4_summoner_entries": ["summoner_id"]}
 
-    def __init__(self, summoner_id: str = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, summoner_id: str = None, platform: str = models.lol.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
     def __getitem__(self, item):
         if not isinstance(item, int):
@@ -117,7 +120,7 @@ class SummonerLeague(PyotCore):
     def __len__(self):
         return len(self.entries)
 
-    def _transform(self, data):
+    def transform(self, data):
         new_data = {}
         new_data["entries"] = data
         return new_data
@@ -135,28 +138,15 @@ class DivisionLeague(SummonerLeague):
 
     class Meta(SummonerLeague.Meta):
         rules = {"league_v4_entries_by_division": ["queue", "tier", "division"]}
-        queue_list = ["RANKED_SOLO_5x5", "RANKED_FLEX_SR"]
-        division_list = ["I", "II", "III", "IV"]
-        tier_list = ["DIAMOND", "PLATINUM", "GOLD", "SILVER", "BRONZE", "IRON"]
-        allow_query = True
 
-    def __init__(self, queue: str = None, division: str = None, tier: str = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, queue: str = None, division: str = None, tier: str = None, platform: str = models.lol.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
     def query(self, page: int = None):
-        '''Add query parameters to the object.'''
-        if page == 0: raise AttributeError("Invalid 'page' attribute, it should be greater than 0")
-        self._meta.query = self._parse_camel(locals())
+        '''Query parameters setter.'''
+        self._meta.query = parse_camelcase(locals())
         return self
 
-    async def _setup(self):
-        if self.queue not in self._meta.queue_list:
-            raise AttributeError(f"Invalid 'queue' attribute, '{self.queue}' was given")
-        if self.division not in self._meta.division_list:
-            raise AttributeError(f"Invalid 'division' attribute, '{self.division}' was given")
-        if self.tier not in self._meta.tier_list:
-            raise AttributeError(f"Invalid 'tier' attribute, '{self.tier}' was given")
-
     @property
-    def summoner(self) -> AttributeError:
+    def summoner(self) -> NoReturn:
         raise AttributeError(f"'{self.__class__.__name__}' object has no attribute 'summoner'")
