@@ -1,8 +1,9 @@
 from typing import List, Iterator
 
-from pyot.utils.cdragon import cdragon_url
+from pyot.conf.model import models
 from pyot.core.functional import cache_indexes, lazy_property
-from .__core__ import PyotCore
+from pyot.utils.lol.cdragon import abs_url
+from .base import PyotCore
 
 
 class ProfileIcon(PyotCore):
@@ -10,33 +11,28 @@ class ProfileIcon(PyotCore):
     icon_path: str
 
     class Meta(PyotCore.Meta):
-        rules = {"cdragon_profile_icon_full": ["id"]}
+        rules = {"cdragon_profile_icon_full": ["version", "locale", "?id"]}
 
-    def __init__(self, id: int = None, locale: str = None):
-        self._lazy_set(locals())
+    def __init__(self, id: int = None, version: str = models.lol.DEFAULT_VERSION, locale: str = models.lol.DEFAULT_LOCALE):
+        self.initialize(locals())
 
     @cache_indexes
-    def _filter(self, indexer, data):
+    def filter(self, indexer, data):
         return indexer.get(self.id, data, "id")
 
-    def _clean(self):
-        if self.locale.lower() == "en_us":
-            self._meta.server = "default"
-        self._hide_load_value("id")
-
     @lazy_property
     def icon_abspath(self) -> str:
-        return cdragon_url(self.icon_path)
+        return abs_url(self.icon_path, self.metaroot.version)
 
 
 class ProfileIcons(PyotCore):
     icons: List[ProfileIcon]
 
     class Meta(PyotCore.Meta):
-        rules = {"cdragon_profile_icon_full": []}
+        rules = {"cdragon_profile_icon_full": ["version", "locale"]}
 
-    def __init__(self, locale: str = None):
-        self._lazy_set(locals())
+    def __init__(self, version: str = models.lol.DEFAULT_VERSION, locale: str = models.lol.DEFAULT_LOCALE):
+        self.initialize(locals())
 
     def __getitem__(self, item):
         if not isinstance(item, int):
@@ -49,9 +45,5 @@ class ProfileIcons(PyotCore):
     def __len__(self):
         return len(self.icons)
 
-    def _clean(self):
-        if self.locale.lower() == "en_us":
-            self._meta.server = "default"
-
-    def _transform(self, data):
+    def transform(self, data):
         return {"icons": data}
