@@ -2,7 +2,9 @@ from datetime import datetime
 from typing import List
 
 from dateutil.parser import parse
-from .__core__ import PyotCore, PyotStatic
+
+from pyot.conf.model import models
+from .base import PyotCore, PyotStatic
 
 # PYOT STATIC OBJECTS
 
@@ -16,12 +18,12 @@ class StatusUpdateData(PyotStatic):
     author: str
     publish: bool
     publish_locations: List[str] # (Legal values: riotclient, riotstatus, game)
+    created_at_strftime: str
+    updated_at_strftime: str
     translations: List[StatusContentData]
-    created_at: datetime
-    updated_at: datetime
 
     class Meta(PyotCore.Meta):
-        raws = ["publish_locations"]
+        raws = {"publish_locations"}
         renamed = {"created_at": "created_at_strftime", "updated_at": "updated_at_strftime"}
 
     @property
@@ -39,15 +41,15 @@ class StatusDetailData(PyotStatic):
     id: int
     maintenance_status: str # (Legal values: scheduled, in_progress, complete)
     incident_severity: str # (Legal values: info, warning, critical)
+    created_at_strftime: str
+    updated_at_strftime: str
+    archive_at_strftime: str
     titles: List[StatusContentData]
     updates: List[StatusUpdateData]
-    created_at: datetime
-    archive_at: datetime
-    updated_at: datetime
     platforms: List[str]
 
     class Meta(PyotCore.Meta):
-        raws = ["platforms"]
+        raws = {"platforms"}
         renamed = {"created_at": "created_at_strftime", "updated_at": "updated_at_strftime", "archive_at": "archive_at_strftime"}
 
     @property
@@ -77,7 +79,7 @@ class Status(PyotCore):
 
     class Meta(PyotCore.Meta):
         rules = {"status_v1_platform_data": []}
-        raws = ["locales"]
+        raws = {"locales"}
 
-    def __init__(self, region: str = None):
-        self._lazy_set(locals())
+    def __init__(self, region: str = models.lor.DEFAULT_REGION):
+        self.initialize(locals())
