@@ -1,5 +1,15 @@
 from datetime import datetime
-from .__core__ import PyotCore
+from typing import TYPE_CHECKING
+
+from pyot.conf.model import models
+from .base import PyotCore
+
+if TYPE_CHECKING:
+    from .league import SummonerLeague
+    from .thirdpartycode import ThirdPartyCode
+    from .profileicon import ProfileIcon
+    from ..riot.account import Account
+    from .match import MatchHistory
 
 
 # PYOT CORE OBJECTS
@@ -12,7 +22,6 @@ class Summoner(PyotCore):
     puuid: str
     profile_icon_id: int
     revision_date_millis: int
-    revision_date: datetime
 
     class Meta(PyotCore.Meta):
         rules = {
@@ -23,8 +32,8 @@ class Summoner(PyotCore):
         }
         renamed = {"summoner_level": "level", "revision_date": "revision_date_millis"}
 
-    def __init__(self, id: str = None, account_id: str = None, name: str = None, puuid: str = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, id: str = None, account_id: str = None, name: str = None, puuid: str = None, platform: str = models.tft.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
     @property
     def revision_date(self) -> datetime:
@@ -43,14 +52,14 @@ class Summoner(PyotCore):
     @property
     def profile_icon(self) -> "ProfileIcon":
         from .profileicon import ProfileIcon
-        return ProfileIcon(id=self.profile_icon_id, locale=self.to_locale(self.platform))
+        return ProfileIcon(id=self.profile_icon_id)
 
     @property
     def account(self) -> "Account":
         from ..riot.account import Account
-        return Account(puuid=self.puuid, region=self.region).set_pipeline("tft")
+        return Account(puuid=self.puuid).pipeline(self.metapipeline.name)
 
     @property
     def match_history(self) -> "MatchHistory":
         from .match import MatchHistory
-        return MatchHistory(puuid=self.puuid, region=self.to_region(self.platform))
+        return MatchHistory(puuid=self.puuid, region=self.region)
