@@ -1,5 +1,12 @@
-from typing import List, Iterator
-from .__core__ import PyotCore, PyotStatic
+from typing import List, Iterator, TYPE_CHECKING
+
+from pyot.conf.model import models
+from pyot.core.functional import parse_camelcase
+from .base import PyotCore, PyotStatic
+
+if TYPE_CHECKING:
+    from ..riot.account import Account
+
 
 # PYOT STATIC OBJECTS
 
@@ -14,7 +21,7 @@ class LeaderboardPlayerData(PyotStatic):
     @property
     def account(self) -> "Account":
         from ..riot.account import Account
-        return Account(puuid=self.puuid, region=self.region).set_pipeline("val")
+        return Account(puuid=self.puuid).pipeline(self.metapipeline.name)
 
 
 # PYOT CORE OBJECTS
@@ -28,8 +35,8 @@ class Leaderboard(PyotCore):
     class Meta(PyotCore.Meta):
         rules = {"ranked_v1_leaderboards": ["act_id"]}
 
-    def __init__(self, act_id: str = None, platform: str = None):
-        self._lazy_set(locals())
+    def __init__(self, act_id: str = None, platform: str = models.val.DEFAULT_PLATFORM):
+        self.initialize(locals())
 
     def __getitem__(self, item):
         if not isinstance(item, int):
@@ -43,6 +50,6 @@ class Leaderboard(PyotCore):
         return len(self.players)
 
     def query(self, size: int = None, start_index: int = None):
-        '''Add query parameters to the object.'''
-        self._meta.query = self._parse_camel(locals())
+        '''Query parameters setter.'''
+        self._meta.query = parse_camelcase(locals())
         return self
